Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(170)

Unified Diff: ui/aura/mus/window_port_mus.h

Issue 2470963002: Makes it possible for clients to directly create WindowTreeHostMus (Closed)
Patch Set: nuke comment Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/aura/mus/window_mus.h ('k') | ui/aura/mus/window_port_mus.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/aura/mus/window_port_mus.h
diff --git a/ui/aura/mus/window_port_mus.h b/ui/aura/mus/window_port_mus.h
index 7b23d06034b5b889f5435b7875911901b003d4ca..f79ef2b3a0c29cddba6eb2895b27ed0a4d10ffa6 100644
--- a/ui/aura/mus/window_port_mus.h
+++ b/ui/aura/mus/window_port_mus.h
@@ -36,9 +36,8 @@ class WindowTreeClientPrivate;
// calling back to WindowTreeClient.
class AURA_EXPORT WindowPortMus : public WindowPort, public WindowMus {
public:
- // See WindowMus's constructor for details on |create_remote_window|.
- explicit WindowPortMus(WindowTreeClient* client,
- bool create_remote_window = true);
+ // See WindowMus's constructor for details on |window_mus_type|.
+ WindowPortMus(WindowTreeClient* client, WindowMusType window_mus_type);
~WindowPortMus() override;
static WindowPortMus* Get(Window* window);
@@ -190,8 +189,7 @@ class AURA_EXPORT WindowPortMus : public WindowPort, public WindowMus {
void NotifyEmbeddedAppDisconnected() override;
// WindowPort:
- std::unique_ptr<WindowPortInitData> OnPreInit(Window* window) override;
- void OnPostInit(std::unique_ptr<WindowPortInitData> init_data) override;
+ void OnPreInit(Window* window) override;
void OnDeviceScaleFactorChanged(float device_scale_factor) override;
void OnWillAddChild(Window* child) override;
void OnWillRemoveChild(Window* child) override;
« no previous file with comments | « ui/aura/mus/window_mus.h ('k') | ui/aura/mus/window_port_mus.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698